aboutsummaryrefslogtreecommitdiffstats
path: root/tap-rpcprogs.c
diff options
context:
space:
mode:
authorAnders Broman <anders.broman@ericsson.com>2006-05-28 20:28:20 +0000
committerAnders Broman <anders.broman@ericsson.com>2006-05-28 20:28:20 +0000
commitf68d6e4c8cc08f1fe570d15e2185d339c81883b8 (patch)
tree2b6a6711cc2ff394c41a98f47a388466a433bccd /tap-rpcprogs.c
parent996d4db495e60df8a627097e3885acdce209132c (diff)
Ethereal->Wireshark
svn path=/trunk/; revision=18235
Diffstat (limited to 'tap-rpcprogs.c')
-rw-r--r--tap-rpcprogs.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/tap-rpcprogs.c b/tap-rpcprogs.c
index ab84e69835..15517517fb 100644
--- a/tap-rpcprogs.c
+++ b/tap-rpcprogs.c
@@ -22,8 +22,8 @@
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/
/* This module provides rpc call/reply SRT statistics to tethereal.
* It is only used by tethereal and not ethereal
*/
#ifdef HAVE_CONFIG_H
@@ -227,7 +227,7 @@ rpcprogs_init(const char *optarg _U_, void* userdata _U_)
error_string=register_tap_listener("rpc", NULL, NULL, NULL, rpcprogs_packet, rpcprogs_draw);
if(error_string){
- fprintf(stderr,"tethereal: Couldn't register rpc,programs tap: %s\n",
+ fprintf(stderr,"twireshark: Couldn't register rpc,programs tap: %s\n",
error_string->str);
g_string_free(error_string, TRUE);
exit(1);
@@ -22,8 +22,8 @@
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/
-/* This module provides rpc call/reply SRT statistics to tethereal.
- * It is only used by tethereal and not ethereal
+/* This module provides rpc call/reply SRT statistics to twireshark.
+ * It is only used by twireshark and not wireshark
*/
#ifdef HAVE_CONFIG_H